==> kdeedu-4.1.0.tar.bz2: kdeedu-4.1.0/marble/src/lib/geodata/scene/GeoSceneFilter.h <==
/*
    Copyright (C) 2008 Torsten Rahn <rahn@kde.org>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef GEOSCENEFILTER_H
#define GEOSCENEFILTER_H

#include <QtCore/QString>
#include <QtCore/QList>

#include "GeoDocument.h"
#include "GeoScenePalette.h"

/**
 * @short Filter of a GeoScene document.
 */

class GeoSceneFilter : public GeoNode {
 public:
    explicit GeoSceneFilter( const QString& name );
    ~GeoSceneFilter();

    QString name() const;
    void setName( const QString& name );

    QString type() const;
    void setType( const QString& type );

    QList<GeoScenePalette*> palette() const;
    void addPalette( GeoScenePalette *palette );
    int removePalette( GeoScenePalette *palette ); //returns # of items removed

 private:
    QString m_name;
    QString m_type;
    QList<GeoScenePalette*> m_palette;

};

#endif // GEOSCENELAYER_H

==> kdeedu-4.2.3.tar.bz2: kdeedu-4.2.3/marble/src/lib/geodata/scene/GeoSceneFilter.h <==
/*
    Copyright (C) 2008 Torsten Rahn <rahn@kde.org>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef GEOSCENEFILTER_H
#define GEOSCENEFILTER_H

#include <QtCore/QString>
#include <QtCore/QList>

#include "GeoDocument.h"
#include "GeoScenePalette.h"

namespace Marble
{

/**
 * @short Filter of a GeoScene document.
 */

class GeoSceneFilter : public GeoNode
{
 public:
    explicit GeoSceneFilter( const QString& name );
    ~GeoSceneFilter();

    QString name() const;
    void setName( const QString& name );

    QString type() const;
    void setType( const QString& type );

    QList<GeoScenePalette*> palette() const;
    void addPalette( GeoScenePalette *palette );
    int removePalette( GeoScenePalette *palette ); //returns # of items removed

 private:
    QString m_name;
    QString m_type;
    QList<GeoScenePalette*> m_palette;

};

}

#endif // GEOSCENELAYER_H
